Global Module Index — Ibid v0.1.1 documentation

### Navigation

- index
- modules |
- Ibid v0.1.1 documentation »

# Global Module Index

I

| I |
| `ibid` |
| `ibid.compat` | Python-version-independent imports of common modules
| `ibid.config` | Configuration File Interface
| `ibid.core` | Ibid Core
| `ibid.event` | Events
| `ibid.plugins` | Processor base class and helpers
| `ibid.utils` | Helper functions for plugins
| `ibid.utils.html` | HTML Parsing helper functions for plugins

### Navigation

- index
- modules |
- Ibid v0.1.1 documentation »